package com.datacloudsec.utils.result;

import java.sql.ResultSet;
import java.sql.ResultSetMetaData;
import java.util.ArrayList;
import java.util.List;
import org.apache.commons.beanutils.BeanUtils;
import org.apache.commons.io.IOUtils;
import org.h2.jdbc.JdbcClob;

/* loaded from: com_datacloudsec_utils_result.jar:com/datacloudsec/utils/result/ListBeanResult.class */
public class ListBeanResult<T> implements IResult {
    private Class<T> beanClazz;

    public ListBeanResult(Class<T> beanClazz) {
        this.beanClazz = beanClazz;
    }

    @Override // com.datacloudsec.utils.result.IResult
    public List<T> parseResult(ResultSet rs) throws Exception {
        List<T> result = new ArrayList<>();
        ResultSetMetaData metaData = rs.getMetaData();
        int colCount = metaData.getColumnCount();
        while (rs.next()) {
            T bean = this.beanClazz.newInstance();
            for (int i = 0; i < colCount; i++) {
                String typeName = metaData.getColumnTypeName(i + 1);
                Object value = null;
                if (typeName.equalsIgnoreCase("TINYINT")) {
                    value = Integer.valueOf(rs.getInt(i + 1));
                } else if (typeName.equalsIgnoreCase("CLOB")) {
                    JdbcClob val = rs.getClob(i + 1);
                    if (val != null) {
                        value = IOUtils.toString(val.getCharacterStream());
                    }
                } else {
                    value = rs.getObject(i + 1);
                }
                if (value != null) {
                    String propertyName = fieldNameToAttr(metaData.getColumnLabel(i + 1).toLowerCase());
                    BeanUtils.setProperty(bean, propertyName, value);
                }
            }
            result.add(bean);
        }
        return result;
    }

    private String fieldNameToAttr(String name) {
        if (name != null) {
            StringBuffer buf = new StringBuffer(name);
            while (true) {
                int index = buf.indexOf("_");
                if (index != -1) {
                    if (index < buf.length()) {
                        char nc = buf.charAt(index + 1);
                        if (nc >= 'a' && nc <= 'z') {
                            nc = (char) (nc - ' ');
                        }
                        buf.setCharAt(index + 1, nc);
                    }
                    buf.deleteCharAt(index);
                } else {
                    return buf.toString();
                }
            }
        } else {
            return name;
        }
    }
}
